@@ -390,6 +390,8 @@ def dict_to_md(
     md_string += md_dict.pop("title", None)
     md_string += md_dict.pop("preamble", None)
 
+    #TODO: Refactor this to use the elegant solution provided here: https://stackoverflow.com/a/49723101/2217577
+
     for k, v in md_dict.items():
         if k in remove_keys:
             continue
@@ -550,7 +552,11 @@ def process_multiple_choice(part_name, parsed_question, data_dict):
             correctness = f"|@ params.{part_name}.{a}.correct @|"
             value = f"|@ params.{part_name}.{a}.value @|"
 
-            html += f"\t<pl-answer correct= {correctness} feedback = '{feedback}' > {value} {units} </pl-answer>\n"
+            ## Hack to remove feedback for Dropdown questions
+            if parsed_question["header"][part_name]['type'] == 'dropdown':
+                html += f"\t<pl-answer correct= {correctness} > {value} {units} </pl-answer>\n"
+            else:
+                html += f"\t<pl-answer correct= {correctness} feedback = '{feedback}' > {value} {units} </pl-answer>\n"
 
     html += "</pl-multiple-choice>\n"
 
@@ -832,8 +838,8 @@ def process_question_md(source_filepath, output_path=None, instructor=False):
                     "Rubric",
                     "Solution",
                     "Comments",
-                    "pl-submission-panel",
-                    "pl-answer-panel",
+                    "pl-submission-panel", #FIXME: This will not remove level 3 headings because it's all a string!
+                    "pl-answer-panel",     #FIXME: This will not remove level 3 headings because it's all a string!
                 ],
             )
             + "\n## Attribution\n\n"
@@ -857,7 +863,7 @@ def process_question_md(source_filepath, output_path=None, instructor=False):
         output_path.write_text(
             "---\n"
             + header_yml
-            + "---\n"
+            + "\n---\n"
             + dict_to_md(
                 body_parts,
             )
@@ -916,7 +922,9 @@ def process_question_pl(source_filepath, output_path=None):
 
     # Question Preamble
     preamble = parsed_q["body_parts"].get("preamble", None)
-    print(f"premable: {preamble}")
+    #TODO: Remove Debugging print statement
+    #print(f"premable: {preamble}")
+    
     if preamble:
         question_html = f"<pl-question-panel>\n<markdown>\n{ preamble }\n</markdown>\n</pl-question-panel>\n\n"
     else:
